@@ -484,7 +484,7 @@ class InvoiceSII(ModelSQL, ModelView):
                     'Repercutida' if invoice.type == 'out' else 'Soportada')),
             ('sii_key', tax.es_sii_tax_key or ''),
             ('operation_key', tax.es_sii_operation_key or ''),
-            ('excluded', tax.es_exclude_from_sii),
+            ('excluded', bool(tax.es_exclude_from_sii)),
             ('product_key', product_type),
             )
 
@@ -617,7 +617,7 @@ class InvoiceSII(ModelSQL, ModelView):
                     'DetalleIVA': list(chain(*tax_values.values())),
                 },
             }
-            detail['FechaRegContable'] = self.invoice.move.date.strftime(
+            detail['FechaRegContable'] = self.invoice.move.post_date.strftime(
                 '%d-%m-%Y')
             detail['CuotaDeducible'] = str(tax_amount)
         return detail
